# vim: et sta sts ai ts=4 sw=4:
import os
from charmhelpers.core import services, hookenv
from charmhelpers.contrib.cloudfoundry import contexts

__all__ = ['PACKAGES', 'SERVICE_USER', 'JOB_DIR', 'RUN_DIR', 'LOG_DIR',
           'PIDFILE', 'SERVICE_DIR', 'PACKAGES_DIR']

SERVICE_DIR = '/var/vcap'
PACKAGES_DIR = os.path.join(SERVICE_DIR, 'packages')
JOB_DIR = os.path.join(SERVICE_DIR, 'jobs/cf-mysql-broker')
RUN_DIR = os.path.join(SERVICE_DIR, 'sys/run/cf-mysql-broker')
LOG_DIR = os.path.join(SERVICE_DIR, 'sys/log/cf-mysql-broker')
PIDFILE = os.path.join(RUN_DIR, 'unicorn.pid')

#ETCD_CONFIG_FILE = os.path.join(etcd_config_path, 'etcd.conf')
PACKAGES = ['python-jinja2', 'git-core', 'ruby', 'ruby-bundler', 'unicorn',
            'libmysqlclient-dev']
SERVICE_USER = 'vcap'
config_dir = os.path.join(PACKAGES_DIR, 'cf-mysql-broker', 'config')
config_data = hookenv.config()

BrokerContext = {
    'broker_ip': hookenv.unit_get('private-address').encode('utf-8'),
    'unicorn_port': config_data['broker_port'],
    'run_dir': RUN_DIR,
    'log_dir': LOG_DIR,
    'job_dir': JOB_DIR,
}
SERVICES = [
    {
        'service': 'cf-mysql-broker',
        'required_data': [
            BrokerContext, contexts.NatsRelation(),
            contexts.RouterRelation(), contexts.MysqlRelation()
        ],
        'data_ready': [
            services.template(source='settings.yml',
                              target=os.path.join(config_dir, 'settings.yml')),
            services.template(source='database.yml',
                              target=os.path.join(config_dir, 'database.yml')),
            services.template(source='cf-mysql-broker.conf',
                              target='/etc/init/cf-mysql-broker.conf'),
            services.template(source='unicorn.conf.rb',
                              target=os.path.join(JOB_DIR, 'config',
                                                  'unicorn.conf.rb')),
        ],
    }
]
